==> autoinformer-0.1.0.zip: resources/autoloader/class_map.php <==
<?php

return array(
    'Zruchna\\FreePbx\\Autoinformer\\Doctrine\\DBAL\\Type\\DatetimeImmutableUtcType' => __DIR__.'/../../src'.'/Doctrine/DBAL/Type/DatetimeImmutableUtcType.php',
    'Zruchna\\FreePbx\\Autoinformer\\Builder\\IvrDetailBuilder' => __DIR__.'/../../src'.'/Builder/IvrDetailBuilder.php',
    'Zruchna\\FreePbx\\Autoinformer\\Factory\\Repository\\SimpleRepositoryFactory' => __DIR__.'/../../src'.'/Factory/Repository/SimpleRepositoryFactory.php',
    'Zruchna\\FreePbx\\Autoinformer\\Factory\\Doctrine\\EntityManagerFactory' => __DIR__.'/../../src'.'/Factory/Doctrine/EntityManagerFactory.php',
    'Zruchna\\FreePbx\\Autoinformer\\Factory\\Doctrine\\ConnectionFactory' => __DIR__.'/../../src'.'/Factory/Doctrine/ConnectionFactory.php',
    'Zruchna\\FreePbx\\Autoinformer\\Factory\\Doctrine\\EventManagerFactory' => __DIR__.'/../../src'.'/Factory/Doctrine/EventManagerFactory.php',
    'Zruchna\\FreePbx\\Autoinformer\\Factory\\OriginatorFactory' => __DIR__.'/../../src'.'/Factory/OriginatorFactory.php',
    'Zruchna\\FreePbx\\Autoinformer\\Factory\\TinyConsoleApplicationFactory' => __DIR__.'/../../src'.'/Factory/TinyConsoleApplicationFactory.php',
    'Zruchna\\FreePbx\\Autoinformer\\Factory\\ClockFactory' => __DIR__.'/../../src'.'/Factory/ClockFactory.php',
    'Zruchna\\FreePbx\\Autoinformer\\Factory\\Builder\\IvrDetailBuilderFactory' => __DIR__.'/../../src'.'/Factory/Builder/IvrDetailBuilderFactory.php',
    'Zruchna\\FreePbx\\Autoinformer\\Factory\\Dialplan\\DialplanBuilderFactory' => __DIR__.'/../../src'.'/Factory/Dialplan/DialplanBuilderFactory.php',
    'Zruchna\\FreePbx\\Autoinformer\\Task\\OriginateScheduledCallsTask' => __DIR__.'/../../src'.'/Task/OriginateScheduledCallsTask.php',
    'Zruchna\\FreePbx\\Autoinformer\\Clock\\SystemClock' => __DIR__.'/../../src'.'/Clock/SystemClock.php',
    'Zruchna\\FreePbx\\Autoinformer\\Clock\\ClockInterface' => __DIR__.'/../../src'.'/Clock/ClockInterface.php',
    'Zruchna\\FreePbx\\Autoinformer\\Dialplan\\DialplanBuilder' => __DIR__.'/../../src'.'/Dialplan/DialplanBuilder.php',
    'Zruchna\\FreePbx\\Autoinformer\\Dialplan\\Application\\HangupApplication' => __DIR__.'/../../src'.'/Dialplan/Application/HangupApplication.php',
    'Zruchna\\FreePbx\\Autoinformer\\Dialplan\\Application\\AbstractFreePbxApplication' => __DIR__.'/../../src'.'/Dialplan/Application/AbstractFreePbxApplication.php',
    'Zruchna\\FreePbx\\Autoinformer\\Dialplan\\Application\\VerboseApplication' => __DIR__.'/../../src'.'/Dialplan/Application/VerboseApplication.php',
    'Zruchna\\FreePbx\\Autoinformer\\Dialplan\\Application\\DialplanApplicationInterface' => __DIR__.'/../../src'.'/Dialplan/Application/DialplanApplicationInterface.php',
    'Zruchna\\FreePbx\\Autoinformer\\Dialplan\\Application\\DialApplication' => __DIR__.'/../../src'.'/Dialplan/Application/DialApplication.php',
    'Zruchna\\FreePbx\\Autoinformer\\Dialplan\\ApplicationDecorator\\VendorCommentApplicationDecorator' => __DIR__.'/../../src'.'/Dialplan/ApplicationDecorator/VendorCommentApplicationDecorator.php',
    'Zruchna\\FreePbx\\Autoinformer\\Dialplan\\ApplicationDecorator\\AbstractApplicationDecorator' => __DIR__.'/../../src'.'/Dialplan/ApplicationDecorator/AbstractApplicationDecorator.php',
    'Zruchna\\FreePbx\\Autoinformer\\Command\\OriginateScheduledCallsCommand' => __DIR__.'/../../src'.'/Command/OriginateScheduledCallsCommand.php',
    'Zruchna\\FreePbx\\Autoinformer\\Entity\\ScheduledCall' => __DIR__.'/../../src'.'/Entity/ScheduledCall.php',
    'Zruchna\\FreePbx\\Autoinformer\\Entity\\Autoinformer' => __DIR__.'/../../src'.'/Entity/Autoinformer.php',
    'Zruchna\\FreePbx\\Autoinformer\\Entity\\IvrDetail' => __DIR__.'/../../src'.'/Entity/IvrDetail.php',
    'Zruchna\\FreePbx\\Autoinformer\\Entity\\Recording' => __DIR__.'/../../src'.'/Entity/Recording.php',
    'Zruchna\\FreePbx\\Autoinformer\\Contract\\Originator' => __DIR__.'/../../src'.'/Contract/Originator.php',
    'Zruchna\\FreePbx\\Autoinformer\\Repository\\RecordingRepository' => __DIR__.'/../../src'.'/Repository/RecordingRepository.php',
    'Zruchna\\FreePbx\\Autoinformer\\Repository\\IvrDetailRepository' => __DIR__.'/../../src'.'/Repository/IvrDetailRepository.php',
    'Zruchna\\FreePbx\\Autoinformer\\Repository\\ScheduledCallRepository' => __DIR__.'/../../src'.'/Repository/ScheduledCallRepository.php',
    'Zruchna\\FreePbx\\Autoinformer\\Repository\\AbstractSimpleRepository' => __DIR__.'/../../src'.'/Repository/AbstractSimpleRepository.php',
    'Zruchna\\FreePbx\\Autoinformer\\Repository\\AutoinformerRepository' => __DIR__.'/../../src'.'/Repository/AutoinformerRepository.php',
    'Zruchna\\FreePbx\\Autoinformer\\Service\\ActiveCalls' => __DIR__.'/../../src'.'/Service/ActiveCalls.php',
    'Zruchna\\FreePbx\\Autoinformer\\Service\\CallfileOriginator' => __DIR__.'/../../src'.'/Service/CallfileOriginator.php',
);

==> autoinformer-0.3.0.zip: resources/autoloader/class_map.php <==
<?php

return array(
    'Zruchna\\FreePbx\\Autoinformer\\Task\\OriginateScheduledCallsTask' => __DIR__.'/../../src'.'/Task/OriginateScheduledCallsTask.php',
    'Zruchna\\FreePbx\\Autoinformer\\Repository\\IvrDetailRepository' => __DIR__.'/../../src'.'/Repository/IvrDetailRepository.php',
    'Zruchna\\FreePbx\\Autoinformer\\Repository\\AbstractSimpleRepository' => __DIR__.'/../../src'.'/Repository/AbstractSimpleRepository.php',
    'Zruchna\\FreePbx\\Autoinformer\\Repository\\RecordingRepository' => __DIR__.'/../../src'.'/Repository/RecordingRepository.php',
    'Zruchna\\FreePbx\\Autoinformer\\Repository\\AutoinformerRepository' => __DIR__.'/../../src'.'/Repository/AutoinformerRepository.php',
    'Zruchna\\FreePbx\\Autoinformer\\Repository\\ScheduledCallRepository' => __DIR__.'/../../src'.'/Repository/ScheduledCallRepository.php',
    'Zruchna\\FreePbx\\Autoinformer\\Command\\OriginateScheduledCallsCommand' => __DIR__.'/../../src'.'/Command/OriginateScheduledCallsCommand.php',
    'Zruchna\\FreePbx\\Autoinformer\\Contract\\Originator' => __DIR__.'/../../src'.'/Contract/Originator.php',
    'Zruchna\\FreePbx\\Autoinformer\\Service\\ActiveCalls' => __DIR__.'/../../src'.'/Service/ActiveCalls.php',
    'Zruchna\\FreePbx\\Autoinformer\\Service\\CallfileOriginator' => __DIR__.'/../../src'.'/Service/CallfileOriginator.php',
    'Zruchna\\FreePbx\\Autoinformer\\Clock\\SystemClock' => __DIR__.'/../../src'.'/Clock/SystemClock.php',
    'Zruchna\\FreePbx\\Autoinformer\\Clock\\ClockInterface' => __DIR__.'/../../src'.'/Clock/ClockInterface.php',
    'Zruchna\\FreePbx\\Autoinformer\\Util\\TimezoneRegistry' => __DIR__.'/../../src'.'/Util/TimezoneRegistry.php',
    'Zruchna\\FreePbx\\Autoinformer\\Util\\DatetimeUtil' => __DIR__.'/../../src'.'/Util/DatetimeUtil.php',
    'Zruchna\\FreePbx\\Autoinformer\\Factory\\TinyConsoleApplicationFactory' => __DIR__.'/../../src'.'/Factory/TinyConsoleApplicationFactory.php',
    'Zruchna\\FreePbx\\Autoinformer\\Factory\\Repository\\SimpleRepositoryFactory' => __DIR__.'/../../src'.'/Factory/Repository/SimpleRepositoryFactory.php',
    'Zruchna\\FreePbx\\Autoinformer\\Factory\\OriginatorFactory' => __DIR__.'/../../src'.'/Factory/OriginatorFactory.php',
    'Zruchna\\FreePbx\\Autoinformer\\Factory\\Doctrine\\ConnectionFactory' => __DIR__.'/../../src'.'/Factory/Doctrine/ConnectionFactory.php',
    'Zruchna\\FreePbx\\Autoinformer\\Factory\\Doctrine\\EventManagerFactory' => __DIR__.'/../../src'.'/Factory/Doctrine/EventManagerFactory.php',
    'Zruchna\\FreePbx\\Autoinformer\\Factory\\Doctrine\\EntityManagerFactory' => __DIR__.'/../../src'.'/Factory/Doctrine/EntityManagerFactory.php',
    'Zruchna\\FreePbx\\Autoinformer\\Factory\\ClockFactory' => __DIR__.'/../../src'.'/Factory/ClockFactory.php',
    'Zruchna\\FreePbx\\Autoinformer\\Factory\\Dialplan\\DialplanBuilderFactory' => __DIR__.'/../../src'.'/Factory/Dialplan/DialplanBuilderFactory.php',
    'Zruchna\\FreePbx\\Autoinformer\\Factory\\Builder\\IvrDetailBuilderFactory' => __DIR__.'/../../src'.'/Factory/Builder/IvrDetailBuilderFactory.php',
    'Zruchna\\FreePbx\\Autoinformer\\Entity\\Recording' => __DIR__.'/../../src'.'/Entity/Recording.php',
    'Zruchna\\FreePbx\\Autoinformer\\Entity\\Autoinformer' => __DIR__.'/../../src'.'/Entity/Autoinformer.php',
    'Zruchna\\FreePbx\\Autoinformer\\Entity\\IvrDetail' => __DIR__.'/../../src'.'/Entity/IvrDetail.php',
    'Zruchna\\FreePbx\\Autoinformer\\Entity\\ScheduledCall' => __DIR__.'/../../src'.'/Entity/ScheduledCall.php',
    'Zruchna\\FreePbx\\Autoinformer\\Dialplan\\DialplanBuilder' => __DIR__.'/../../src'.'/Dialplan/DialplanBuilder.php',
    'Zruchna\\FreePbx\\Autoinformer\\Dialplan\\ApplicationDecorator\\VendorCommentApplicationDecorator' => __DIR__.'/../../src'.'/Dialplan/ApplicationDecorator/VendorCommentApplicationDecorator.php',
    'Zruchna\\FreePbx\\Autoinformer\\Dialplan\\ApplicationDecorator\\AbstractApplicationDecorator' => __DIR__.'/../../src'.'/Dialplan/ApplicationDecorator/AbstractApplicationDecorator.php',
    'Zruchna\\FreePbx\\Autoinformer\\Dialplan\\Application\\VerboseApplication' => __DIR__.'/../../src'.'/Dialplan/Application/VerboseApplication.php',
    'Zruchna\\FreePbx\\Autoinformer\\Dialplan\\Application\\DialApplication' => __DIR__.'/../../src'.'/Dialplan/Application/DialApplication.php',
    'Zruchna\\FreePbx\\Autoinformer\\Dialplan\\Application\\DialplanApplicationInterface' => __DIR__.'/../../src'.'/Dialplan/Application/DialplanApplicationInterface.php',
    'Zruchna\\FreePbx\\Autoinformer\\Dialplan\\Application\\AbstractFreePbxApplication' => __DIR__.'/../../src'.'/Dialplan/Application/AbstractFreePbxApplication.php',
    'Zruchna\\FreePbx\\Autoinformer\\Dialplan\\Application\\HangupApplication' => __DIR__.'/../../src'.'/Dialplan/Application/HangupApplication.php',
    'Zruchna\\FreePbx\\Autoinformer\\Builder\\IvrDetailBuilder' => __DIR__.'/../../src'.'/Builder/IvrDetailBuilder.php',
);
